package Hawat::Controller::Network;
use strict;
use warnings;
use Moose;
use namespace::autoclean;

use Data::Dumper;
use Mentat::Core qw(:c_hawat);

#-------------------------------------------------------------------------------
# Initialization section
#-------------------------------------------------------------------------------

BEGIN { extends 'Hawat::Controller::Secure'; }

__PACKAGE__->config(
    class       => 'Hawat::Controller::Network',
    constructor => 'new',
);

=head1 NAME

Hawat::Controller::Network - Catalyst controller for filter management

=head1 DESCRIPTION

Catalyst controller for handling actions related to filter management.

=head1 ACTIONS

=cut

#-------------------------------------------------------------------------------
# Implementation section
#-------------------------------------------------------------------------------

=head2 index

Default controller action, redirects to the 'list' action

=cut

sub index :Path :Args(0) {
    my ( $self, $c ) = @_;
    $c->response->redirect($c->uri_for($self->action_for('list')));
}

=head2 list

View the list of all networks stored in the database

=cut

sub list :Local :Args(0) {
    my ($self, $c) = @_;

    # Store the back link to this request
    $c->session->{backlink} = $c->req->uri;

    # Configure and forward to '/dbitem/find' action
    my $conf = $self->_dbicnf(
        operation => 'listNetworks',
        limit  => $c->cfg('result_limit'),
        sortby => 'id',
        sort   => 'asc',
    );
    $c->forward(HAWAT_DBI_LIST, [$conf]);

    # TODO: make use of 'nowrap' for ajax queries
    #$c->stash(nowrap => 1);

    # Optionally dump interesting variables - dependent on the DEVEL switch
    #$self->dump_variable($c, 'Field', $variable) if $c->cfg('devel');

    # Render the view
    # NOTE: No need for that now, it will be rendered automagically, when the
    # 'end' method is called (see the Hawat::Controller::Root for details)
    #$c->forward($c->view(HAWAT_VIEW_HTML));
}

=head2 bulkadd

Create bulk of network records

=cut

#sub bulkadd :Local :Args(1) { # Switch to let the framework handle the error reporting
sub bulkadd :Local {
    my ($self, $c) = @_;

    # Determine the backlink to which to return to
    my $backlink = $c->session->{backlink} || $c->uri_for('/network');

    # Configure and forward to '/dbitem/addNetwork' action
    my $conf = $self->_dbicnf(
        backlink => $backlink,
        operation => 'addNetworks',
        subitem => 'network',
    );
    $c->forward(HAWAT_DBI_DO, [$conf]);

    # Fetch the list of all currently defined groups
    my $abuse_groups = $c->model('Groups')->list();
    $c->stash(group_list => $abuse_groups);

    # Choose the common create+updateNetwork template
    $c->stash(template => 'network/bulkadd');

    # Optionally dump interesting variables - dependent on the DEVEL switch
    #$self->dump_variable($c, 'Field', $variable) if $c->cfg('devel');

    # Render the view
    # NOTE: No need for that now, it will be rendered automagically, when the
    # 'end' method is called (see the Hawat::Controller::Root for details)
    #$c->forward($c->view(HAWAT_VIEW_HTML));
}

=head2 bulkrem

Remove bulk of network records

=cut

#sub bulkrem :Local :Args(1) { # Switch to let the framework handle the error reporting
sub bulkrem :Local {
    my ($self, $c) = @_;

    # Determine the backlink to which to return to
    my $backlink = $c->session->{backlink} || $c->uri_for('/network');

    # Configure and forward to '/dbitem/addNetwork' action
    my $conf = $self->_dbicnf(
        backlink => $backlink,
        operation => 'removeNetworks',
        subitem => 'network',
    );
    $c->forward(HAWAT_DBI_DO, [$conf, $c]);

    # Fetch the list of all currently defined groups
    my $abuse_groups = $c->model('Groups')->list();
    $c->stash(group_list => $abuse_groups);

    # Choose the common create+updateNetwork template
    $c->stash(template => 'network/bulkrem');

    # Optionally dump interesting variables - dependent on the DEVEL switch
    #$self->dump_variable($c, 'Field', $variable) if $c->cfg('devel');

    # Render the view
    # NOTE: No need for that now, it will be rendered automagically, when the
    # 'end' method is called (see the Hawat::Controller::Root for details)
    #$c->forward($c->view(HAWAT_VIEW_HTML));
}

# _dbicnf(%)
#
#  Usage     :
#  Purpose   :
#  Arguments :
#  Returns   :
#  Throws    : Dies, if not invoked on object instance

sub _dbicnf(%)
{
    my ($self, %cnf_a) = @_;
    my $cnf = {
            controller => 'Network',
            model      => HAWAT_MODEL_GROUPS(),
            items      => 'Networks',
            item       => 'Network',
            menu       => 'admin',
        };
    foreach my $k (keys %cnf_a) {
        $cnf->{$k} = $cnf_a{$k};
    }
    return $cnf;
}

=head1 AUTHOR

 Jan Mach
 Cesnet, z.s.p.o
 jan.mach@cesnet.cz
 http://www.cesnet.cz

=head1 LICENSE

This library is free software. You can redistribute it and/or modify
it under the same terms as Perl itself.

=cut

__PACKAGE__->meta->make_immutable;

1;
